==> teplotech-markup-1.0.3.tgz: package/webpack.config.js <==
var webpack = require('webpack')
var CopyWebpackPlugin = require('copy-webpack-plugin')
var path = require('path')

module.exports = {
	target: 'web',
	devtool: 'source-map',
	context: __dirname + '/src/scripts',
	/*
	 * The entry point for the bundle
	 *
	 * See: http://webpack.github.io/docs/configuration.html#entry
	 */
	entry: {
		main: './app',
		common: [
			'jquery', 'hammerjs', 'underscore',
			// polyfills:
			'core-js/es6/array',
			'core-js/es6/object',
			'core-js/es6/function',
			'core-js/es6/string'
		],
	},
	module: {
		loaders: [
			//{test: /\.css$/, loader: "style!css"},
			//{test: /\.css$/, loader: "url-loader?mimetype=text/css"},
			//{test: /\.(woff|svg|ttf|eot)([\?]?.*)$/, loader: "file-loader?name=[name].[ext]"},
			/*{
				test: /^modernizr.json$/,
				loader: "modernizr"
			},*/

			// Attach jQuery to the real window object
			{
				test: require.resolve('jquery'),
				loader: 'expose?jQuery!expose?$'
			}

			/*{
				test: /\.jsx?$/,
				exclude: /(node_modules|bower_components)/,
				//loader: 'babel',
				//query: { presets: ['es2015'] }
				loaders: ['es3ify', 'babel?' + JSON.stringify({
					presets: ['es2015-loose-ie8']
				})],
			}*/
		]
	},
	plugins: [
		new webpack.OldWatchingPlugin(),
		/*
		 * Plugin: CommonsChunkPlugin
		 * Description: Shares common code between the pages.
		 * It identifies common modules and put them into a commons chunk.
		 *
		 * See: https://webpack.github.io/docs/list-of-plugins.html#commonschunkplugin
		 * See: https://github.com/webpack/docs/wiki/optimization#multi-page-app
		 */
		new webpack.optimize.CommonsChunkPlugin('common', 'common.js'),
		new webpack.optimize.UglifyJsPlugin({
			compress: {
		   		warnings: false
			}
		}),

		/*
		 * Plugin: CopyWebpackPlugin
		 * Description: Copy files and directories in webpack.
		 *
		 * Copies project static assets.
		 *
		 * See: https://www.npmjs.com/package/copy-webpack-plugin
		 */
		new CopyWebpackPlugin([
			{
				from: __dirname + '/src/fonts',
				to: __dirname + '/dist/fonts'
			},
			{
				from: __dirname + '/src/images',
				to: __dirname + '/dist/img',
				ignore: ['base64/**/*', 'sprites/**/*']
			},
			{
				from: __dirname + '/src/*.html',
				to: __dirname + '/dist'
			}
		]),

		new webpack.ProvidePlugin({
			$:               'jquery',
			jQuery:          'jquery',
			'window.jQuery': 'jquery',
			_:               'underscore'
		})
	],
	output: {
		library: 'App',
		libraryTarget: 'var',
		publicPath: '/js/',
		path: __dirname + '/dist/js',
		filename: '[name].js',
		chunkFilename: 'chunk-[id].js'
	}
}

==> teplotech-markup-1.1.4.tgz: package/webpack.config.js <==
var webpack = require('webpack')
var CopyWebpackPlugin = require('copy-webpack-plugin')
var path = require('path')

module.exports = {
	target: 'web',
	devtool: 'source-map',
	context: __dirname + '/src/scripts',
	/*
	 * The entry point for the bundle
	 *
	 * See: http://webpack.github.io/docs/configuration.html#entry
	 */
	entry: {
		main: './app'
	},
	module: {
		loaders: [
			//{test: /\.css$/, loader: "style!css"},
			//{test: /\.css$/, loader: "url-loader?mimetype=text/css"},
			//{test: /\.(woff|svg|ttf|eot)([\?]?.*)$/, loader: "file-loader?name=[name].[ext]"},
			/*{
				test: /^modernizr.json$/,
				loader: "modernizr"
			},*/

			// Attach jQuery to the real window object
			/*{
				test: require.resolve('jquery'),
				loader: 'expose?jQuery!expose?$'
			}*/

			/*{
				test: /\.jsx?$/,
				exclude: /(node_modules|bower_components)/,
				//loader: 'babel',
				//query: { presets: ['es2015'] }
				loaders: ['es3ify', 'babel?' + JSON.stringify({
					presets: ['es2015-loose-ie8']
				})],
			}*/
		]
	},
	plugins: [
		new webpack.OldWatchingPlugin(),
		/*
		 * Plugin: CommonsChunkPlugin
		 * Description: Shares common code between the pages.
		 * It identifies common modules and put them into a commons chunk.
		 *
		 * See: https://webpack.github.io/docs/list-of-plugins.html#commonschunkplugin
		 * See: https://github.com/webpack/docs/wiki/optimization#multi-page-app
		 */
		//new webpack.optimize.CommonsChunkPlugin('common', 'common.js'),
		new webpack.optimize.UglifyJsPlugin({
			compress: {
		   		warnings: false
			}
		}),

		/*
		 * Plugin: CopyWebpackPlugin
		 * Description: Copy files and directories in webpack.
		 *
		 * Copies project static assets.
		 *
		 * See: https://www.npmjs.com/package/copy-webpack-plugin
		 */
		new CopyWebpackPlugin([
			{
				from: __dirname + '/src/fonts',
				to: __dirname + '/dist/fonts'
			},
			{
				from: __dirname + '/src/images',
				to: __dirname + '/dist/img',
				ignore: ['base64/**/*', 'sprites/**/*']
			},
			{
				from: __dirname + '/src/*.html',
				to: __dirname + '/dist'
			}
		]),

		/*new webpack.ProvidePlugin({
			$:               'jquery',
			jQuery:          'jquery',
			'window.jQuery': 'jquery',
			_:               'underscore'
		})*/
	],
	output: {
		library: 'App',
		libraryTarget: 'var',
		publicPath: '/js/',
		path: __dirname + '/dist/js',
		filename: '[name].js',
		chunkFilename: 'chunk-[id].js'
	}
}
